/******************************************************************************
 * @file:		gauge_config.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	30. jan. 2016
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#ifndef GAUGE_CONFIG_H_
#define GAUGE_CONFIG_H_

#include <stdbool.h>
#include <stdint.h>

#include "em_i2c.h"
#include "em_gpio.h"
#include "em_cmu.h"

/*******************************************************************************
 * 									Settings
 *******************************************************************************/

#define GAUGE_ADDRESS			0x55 << 1
#define GAUGE_FREQ				I2C_FREQ_STANDARD_MAX


/*******************************************************************************
 * 								Register commands
 *******************************************************************************/

/* Valid for BQ27510-G3 only! */
#define GAUGE_CONTROL			(uint8_t[]){0x00, 0x01}//((0x00 << 8) | 0x01)
#define GAUGE_AT_RATE			(uint8_t[]){0x02, 0x03}//((0x02 << 8) | 0x03)	//0,1
#define GAUGE_AT_RATE_TTE		(uint8_t[]){0x04, 0x05}//((0x04 << 8) | 0x05)	//2,3
#define GAUGE_TEMP				(uint8_t[]){0x06, 0x07}//((0x06 << 8) | 0x07) 	//4,5
#define GAUGE_VOLTAGE			(uint8_t[]){0x08, 0x09}//((0x08 << 8) | 0x09)	//6,7
#define GAUGE_FLAGS				(uint8_t[]){0x0A, 0x0B}//((0x0A << 8) | 0x0B)	//8,9
#define GAUGE_NOM_AVAIL_CAP		(uint8_t[]){0x0C, 0x0D}//((0x0C << 8) | 0x0D)	//10,11
#define GAUGE_FULL_AVAIL_CAP	(uint8_t[]){0x0E, 0x0F}//((0x0E << 8) | 0x0F)	//12,13
#define GAUGE_REMAIN_CAP		(uint8_t[]){0x10, 0x11}//((0x10 << 8) | 0x11)	//14,15
#define GAUGE_FULL_CHRG_CAP		(uint8_t[]){0x12, 0x13}//((0x12 << 8) | 0x13)	//16,17
#define GAUGE_AVRG_CURR			(uint8_t[]){0x14, 0x15}//((0x14 << 8) | 0x15)	//18,19
#define GAUGE_TIME_TO_EMPTY		(uint8_t[]){0x16, 0x17}//((0x16 << 8) | 0x17)	//20,21
#define GAUGE_STANDBY_CURR		(uint8_t[]){0x18, 0x19}//((0x18 << 8) | 0x19)	//22,23
#define GAUGE_STANDBY_TTE		(uint8_t[]){0x1A, 0x1B}//((0x1A << 8) | 0x1B)	//24,25
#define GAUGE_STATE_OF_HEALTH	(uint8_t[]){0x1C, 0x1D}//((0x1C << 8) | 0x1D)	//26,27
#define GAUGE_CYCLE_COUNT		(uint8_t[]){0x1E, 0x1F}//((0x1E << 8) | 0x1F)	//28,29
#define GAUGE_STATE_OF_CHRG		(uint8_t[]){0x20, 0x21}//((0x20 << 8) | 0x21)	//30,31
#define GAUGE_INST_CURR			(uint8_t[]){0x22, 0x23}//((0x22 << 8) | 0x23)	//32,33
#define GAUGE_INTERNAL_TEMP		(uint8_t[]){0x28, 0x29}//((0x28 << 8) | 0x29)	//34,35
#define GAUGE_RES_SCALE			(uint8_t[]){0x2A, 0x2B}//((0x2A << 8) | 0x2B)	//36,37
#define GAUGE_OP_CONFIG			(uint8_t[]){0x2C, 0x2D}//((0x2C << 8) | 0x2D)	//38,39
#define GAUGE_DESIGN_CAP		(uint8_t[]){0x2E, 0x2F}//((0x2E << 8) | 0x2F)	//40,41

#define GAUGE_CONTROL_STATUS	(uint8_t[]){0x00, 0x00}


/*******************************************************************************
 * 								Ports and pins
 *******************************************************************************/

#define GAUGE_I2C_PORT       	gpioPortA
#define GAUGE_BI_PORT			gpioPortE

#define GAUGE_SDA_PIN	 		0
#define GAUGE_SCL_PIN			1
#define GAUGE_BI_PIN			15

/*******************************************************************************
 * 								I2C Settings
 *******************************************************************************/

#define GAUGE_I2C				I2C0
#define GAUGE_CMUCLOCK			cmuClock_I2C0

#define GAUGE_ROUTE 			I2C_ROUTE_SCLPEN | I2C_ROUTE_SDAPEN
#define GAUGE_LOC          		I2C_ROUTE_LOCATION_LOC0


#endif /* GAUGE_CONFIG_H_ */
