/******************************************************************************
 * @file:		gps_config.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	26. jan. 2016
 ******************************************************************************
 *	Configuration parameters for the U-blox NEO-7P GPS module.
 ******************************************************************************/

#ifndef GPS_CONFIG_H_
#define GPS_CONFIG_H_

#include "em_usart.h"
#include "em_gpio.h"
#include "em_cmu.h"

/*******************************************************************************
 * 								Device settings
 *******************************************************************************/

#define GPS_USE_TX_READY	1
#define GPS_TXREADY_PIN		13 	/* EXTINT (PIO13), ANT_ON (PIO16) */
#define GPS_TXREADY_THRES	10  /* 80 byte threshold before TX ready pin goes active */
#define GPS_TXREADY_POL		0	/* Active high */
#define GPS_EXT_TX_TIM		1	/* Extended TX timeout */

#define GPS_SBAS_USAGE		0x07	/* Ranging, diff. corrections and integrity */
#define GPS_SBAS_SCANMODE	0x51	/* Only allow EGNOS satellites for Europe (PRN 120, 124, 126) */

#define GPS_IN_PROTOCOLS	0x01	/* Only UBX protocol allowed */
#define GPS_OUT_PROTOCOLS	0x01	/* Only UBX protocol allowed */

#define GPS_STANDARD_NMEA_MSG				\
(uint8_t[]){								\
	0xF0, 0x00, 0xF0, 0x01, /* GGA, GLL */	\
	0xF0, 0x03, 0xF0, 0x04,	/* GSV, RMC */	\
	0xF0, 0x05,	/* VTG */					\
	0xFF									\
}

/*******************************************************************************
 * 								Ports and pins
 *******************************************************************************/

#define GPS_GPIO_PORT 		gpioPortC

#define GPS_PWR_PIN			14
#define GPS_TIMEPULSE_PIN	13
#define GPS_EXTINT_PIN		12
#define GPS_RESET_PIN		11

/*******************************************************************************
 * 								SPI Settings
 *******************************************************************************/

#define GPS_USART       	USART0
#define GPS_LOC        		USART_ROUTE_LOCATION_LOC1
#define GPS_CMUCLOCK    	cmuClock_USART0
#define GPS_ROUTE			USART_ROUTE_TXPEN | USART_ROUTE_RXPEN

#define GPS_SPI_CLOCK		5000000	// 5MHz


#endif /* GPS_CONFIG_H_ */
