/******************************************************************************
 * @file:		imu_config.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	26. jan. 2016
 ******************************************************************************
 *	Configuration parameters for InvenSense MPU-9250 IMU
 ******************************************************************************/

#ifndef IMU_CONFIG_H_
#define IMU_CONFIG_H_

#include "em_gpio.h"

/*******************************************************************************
 * 							Register addresses
 *******************************************************************************/

#define IMU_PACKET_END			0xFF
#define IMU_REGISTER_READ		0x80

#define IMU_ACCEL_XOUT_H		0x3B | IMU_REGISTER_READ
#define IMU_ACCEL_XOUT_L		0x3C | IMU_REGISTER_READ
#define IMU_ACCEL_YOUT_H		0x3D | IMU_REGISTER_READ
#define IMU_ACCEL_YOUT_L		0x3E | IMU_REGISTER_READ
#define IMU_ACCEL_ZOUT_H		0x3F | IMU_REGISTER_READ
#define IMU_ACCEL_ZOUT_L		0x40 | IMU_REGISTER_READ

#define IMU_TEMP_OUT_H			0x41 | IMU_REGISTER_READ
#define IMU_TEMP_OUT_L			0x42 | IMU_REGISTER_READ

#define IMU_GYRO_XOUT_H			0x43 | IMU_REGISTER_READ
#define IMU_GYRO_XOUT_L			0x44 | IMU_REGISTER_READ
#define IMU_GYRO_YOUT_H			0x45 | IMU_REGISTER_READ
#define IMU_GYRO_YOUT_L			0x46 | IMU_REGISTER_READ
#define IMU_GYRO_ZOUT_H			0x47 | IMU_REGISTER_READ
#define IMU_GYRO_ZOUT_L			0x48 | IMU_REGISTER_READ

#define IMU_WHOAMI				0x75 | IMU_REGISTER_READ
#define IMU_USER_CTRL			0x6A
#define IMU_PWR_MGMT_1			0x6B
#define IMU_PWR_MGMT_2			0x6C

/*******************************************************************************
 * 							Default register packets
 *******************************************************************************/

#define IMU_GYRO_PACKET						\
(uint8_t[]){								\
	IMU_GYRO_XOUT_H, IMU_GYRO_XOUT_L,		\
	IMU_GYRO_YOUT_H, IMU_GYRO_YOUT_L,		\
	IMU_GYRO_ZOUT_H, IMU_GYRO_ZOUT_L,		\
	IMU_PACKET_END							\
}

#define IMU_ACCEL_PACKET					\
(uint8_t[]){								\
	IMU_ACCEL_XOUT_H, IMU_ACCEL_XOUT_L,		\
	IMU_ACCEL_YOUT_H, IMU_ACCEL_YOUT_L,		\
	IMU_ACCEL_ZOUT_H, IMU_ACCEL_ZOUT_L,		\
	IMU_PACKET_END							\
}

#define IMU_TEMP_PACKET						\
(uint8_t[]){								\
	IMU_TEMP_OUT_H, IMU_TEMP_OUT_L,			\
	IMU_PACKET_END							\
}


/*******************************************************************************
 * 								Ports and pins
 *******************************************************************************/

#define IMU_GPIO_PORT	gpioPortD

#define IMU_FSYNC_PIN	6
#define IMU_INT_PIN		5

#define IMU_SPI_CLOCK	1000000 // 1MHz


#endif /* IMU_CONFIG_H_ */
