/******************************************************************************
 * @file:		radio_config.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	26. jan. 2016
 ******************************************************************************
 *	Configuration parameters for the Radiocrafts TinyMesh RC1180HP radio module.
 *
 *	The Interrupt handlers must also be modified if USART(UART) number is changed.
 ******************************************************************************/

#ifndef RADIO_CONFIG_H_
#define RADIO_CONFIG_H_

#include "em_usart.h"
#include "em_gpio.h"

/*******************************************************************************
 * 								UART Settings
 *******************************************************************************/

#define RADIO_UART          	USART2
#define RADIO_CMUCLOCK        	cmuClock_USART2

#define RADIO_ROUTE 			USART_ROUTE_RXPEN | USART_ROUTE_TXPEN
#define RADIO_LOC             	USART_ROUTE_LOCATION_LOC1

#define RADIO_BAUDRATE			115200
#define RADIO_BAUDRATE_FACTORY 	19200

#define RADIO_DATABITS		 	usartDatabits8
#define RADIO_PARITY			usartNoParity
#define RADIO_STOPBITS		 	usartStopbits1


#define RADIO_RX_IRQn		 	USART2_RX_IRQn
#define RADIO_TX_IRQn		 	USART2_TX_IRQn

#define RADIO_BAUDRATES  	\
(uint8_t[]){				\
				\
}

#define RADIO_UART_INIT		\
{							\
	usartEnable,			\
	0,						\
	RADIO_BAUDRATE,			\
	usartOVS16,				\
	RADIO_DATABITS,			\
	RADIO_PARITY,			\
	RADIO_STOPBITS			\
}

/*******************************************************************************
 * 							Settings
 *******************************************************************************/

#define RADIO_MAX_PACKET_LEN	120

#define RADIO_MAX_CONFIG_LEN	50

#define RADIO_USE_RTS			1
#define RADIO_USE_CTS			1

#define RADIO_WAIT_FOR_CTS		1000 /* Time in ms to wait before timeout */
#define RADIO_WAIT_FOR_PROMPT	500

#define RADIO_DEFAULT_CH				13
#define RADIO_DEFAULT_PWR				2	/* 10dbm */
#define RADIO_DEFAULT_DATA_RATE			5	/* 76.8kbit */
#define RADIO_DEFAULT_PROTOCOL_MODE		1 	/* Transparent mode */
#define RADIO_DEFAULT_MAX_JUMP			20
#define RADIO_DEFAULT_MAX_JUMP_CNT		30
#define RADIO_DEFAULT_SERIAL_TIMEOUT	13 	/* timeout in ms before packet is transmitted (2ms is added by radio module as well) */
#define RADIO_DEFAULT_CTS_HOLD			6	/* CTS hold time in 10ms steps (only on gateway) */
#define RADIO_DEFAULT_RTS_SLEEP			0   /* Use RTS/Sleep pin for RTS */
#define RADIO_DEFAULT_CLUSTER_LIM		10	/* Clustered node device limit: min 5, max 100*/
#define RADIO_DEFAULT_CLUSTER_RSSI		60

 /*******************************************************************************/

#if DEBUG_OPERATION
#define RADIO_DEFAULT_IND_TIMEOUT	255 /* Always on, for testing */
#else
#define RADIO_DEFAULT_IND_TIMEOUT	60 /* Turn off after 60 min */
#endif

#if RADIO_USE_RTS
#define RADIO_DEFAULT_FLOW_CTRL		0x03
#elif RADIO_USE_CTS
#define RADIO_DEFAULT_FLOW_CTRL 	0x01
#else
#define RADIO_DEFAULT_FLOW_CTRL		0x00
#endif

#if RADIO_BAUDRATE == 115200
#define RADIO_DEFAULT_BAUD			0x0A
#elif RADIO_BAUDRATE == 230400
#define RADIO_DEFAULT_BAUD			0x0B
#else
#define RADIO_DEFAULT_BAUD			0x05
#endif

/*******************************************************************************
 * 							Configuration parameters
 *******************************************************************************/


#define RADIO_CONFIG_END			'^'
#define RADIO_PROMPT				'>'

#define RADIO_RSSI					'S'
#define RADIO_TEMP					'U'
#define RADIO_VOLTAGE				'V'
#define RADIO_READ_MEM_CONFIG		'Y'
#define RADIO_MEM_CONFIG			'M'
#define RADIO_EXIT_CONFIG			'X'
#define RADIO_SET_ROUTER_MODE		(uint8_t[]){'R', RADIO_CONFIG_END}
#define RADIO_SET_GATEWAY_MODE		(uint8_t[]){'G', RADIO_CONFIG_END}
#define RADIO_SET_END_MODE			(uint8_t[]){'N', RADIO_CONFIG_END}
#define RADIO_SLEEP					(uint8_t[]){'Z', RADIO_CONFIG_END}

#define RADIO_MEM_EXIT				0xFF
#define RADIO_SET_AES_KEY			(uint8_t[]){'K', 7, RADIO_CONFIG_END}
#define RADIO_CAL_MEM_CONFIG		(uint8_t[]){'H', 'W', RADIO_CONFIG_END}
#define RADIO_RESET_MEM				(uint8_t[]){'@','T','M', RADIO_CONFIG_END}

#define RADIO_MEM_RF_CH				0x00
#define RADIO_MEM_RF_PWR			0x01
#define RADIO_MEM_RF_DATA_RATE		0x02
#define RADIO_MEM_PROTOCOL_MODE		0x03
#define RADIO_MEM_HIAM				0x06
#define RADIO_MEM_CCT				0x08
#define RADIO_MEM_MAX_JUMP			0x09
#define RADIO_MEM_MAX_JUMP_COUNT	0x0A
#define RADIO_MEM_MAX_PACKET_LAT	0x0B
#define RADIO_MEM_TRANS_RETRY_LIM	0x0C
#define RADIO_MEM_PACKET_TIMEOUT	0x0D
#define RADIO_MEM_DEV_TYPE			0x0E
#define RADIO_MEM_CTS_HOLD			0x2B
#define RADIO_MEM_LOCATOR			0x2C
#define RADIO_MEM_UID0				0x2D
#define RADIO_MEM_UID1				0x2E
#define RADIO_MEM_UID2				0x2F
#define RADIO_MEM_UID3				0x30
#define RADIO_MEM_SID0				0x31
#define RADIO_MEM_SID1				0x32
#define RADIO_MEM_SID2				0x33
#define RADIO_MEM_SID3				0x34


#define RADIO_MEM_UART_BAUD			0x35
#define RADIO_MEM_UART_BITS			0x36
#define RADIO_MEM_UART_PARITY		0x37
#define RADIO_MEM_UART_STOP			0x38
#define RADIO_MEM_UART_FLOWCTRL		0x3A

#define RADIO_MEM_SECURITY_LEV		0x51
#define RADIO_MEM_INDICATORS		0x59
#define RADIO_MEM_SLEEP_RTS			0x5D
#define RADIO_MEM_CLUSTER_LIM		0x63
#define RADIO_MEM_CLUSTER_RSSI_LIM	0x64
#define RADIO_MEM_JAM_DETECT		0x66
#define RADIO_MEM_JAM_PORT			0x67

/*******************************************************************************
 * 							Default configuration packets
 *******************************************************************************/


#define RADIO_DEFAULT_CONFIG	/* Registers not mentioned are kept from factory default */	\
(uint8_t[]){													\
	RADIO_MEM_RF_PWR, 			RADIO_DEFAULT_PWR,				\
	RADIO_MEM_RF_CH,			RADIO_DEFAULT_CH, 				\
	RADIO_MEM_RF_DATA_RATE,		RADIO_DEFAULT_DATA_RATE,		\
	RADIO_MEM_PROTOCOL_MODE,	RADIO_DEFAULT_PROTOCOL_MODE, 	\
	RADIO_MEM_MAX_JUMP, 		RADIO_DEFAULT_MAX_JUMP,			\
	RADIO_MEM_MAX_JUMP_COUNT,	RADIO_DEFAULT_MAX_JUMP_CNT,		\
	RADIO_MEM_PACKET_TIMEOUT, 	RADIO_DEFAULT_SERIAL_TIMEOUT,	\
	RADIO_MEM_SLEEP_RTS, 		RADIO_DEFAULT_RTS_SLEEP,		\
	RADIO_MEM_UART_BAUD,		RADIO_DEFAULT_BAUD,				\
	RADIO_MEM_UART_FLOWCTRL,	RADIO_DEFAULT_FLOW_CTRL,		\
	RADIO_MEM_INDICATORS,		RADIO_DEFAULT_IND_TIMEOUT,		\
	RADIO_MEM_CLUSTER_LIM,		RADIO_DEFAULT_CLUSTER_LIM,		\
	RADIO_MEM_CLUSTER_RSSI_LIM, RADIO_DEFAULT_CLUSTER_RSSI,		\
	RADIO_MEM_CTS_HOLD,         RADIO_DEFAULT_CTS_HOLD,         \
	RADIO_CONFIG_END											\
}


#define RADIO_UID_MESSAGE	\
(uint8_t[]){				\
	RADIO_MEM_UID0,	0,		\
	RADIO_MEM_UID1,	0,		\
	RADIO_MEM_UID2, 0, 		\
	RADIO_MEM_UID3, 0,   	\
	RADIO_CONFIG_END		\
}


#define RADIO_SID_MESSAGE	\
(uint8_t[]){				\
	RADIO_MEM_SID0,	0,		\
	RADIO_MEM_SID1,	0,		\
	RADIO_MEM_SID2, 0, 		\
	RADIO_MEM_SID3, 0,   	\
	RADIO_CONFIG_END		\
}


/*******************************************************************************
 * 								Ports and pins
 *******************************************************************************/

#define RADIO_GPIO_PORT       	gpioPortA
#define RADIO_RESET_PORT		gpioPortC
#define RADIO_CONFIG_PORT	 	gpioPortB
#define RADIO_RTS_PORT			gpioPortB
#define RADIO_CTS_PORT			gpioPortB
#define RADIO_UART_PORT			gpioPortB

#define RADIO_GPIO_PIN		 	4
#define RADIO_RESET_PIN			0 /* Active low */
#define RADIO_CONFIG_PIN		0 /* Active low */
#define RADIO_RTS_PIN        	1
#define RADIO_CTS_PIN        	2 /* Active low */
#define RADIO_TX_PIN		    3
#define RADIO_RX_PIN         	4


#endif /* RADIO_CONFIG_H_ */
