/******************************************************************************
 * @file:		radio_driver.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	26. jan. 2016
 ******************************************************************************
*	Driver for the Radiocrafts RC11xx- TinyMesh module.
 ******************************************************************************/


#ifndef RADIO_DRIVER_H_
#define RADIO_DRIVER_H_


#include <stdbool.h>
#include <stdint.h>

/*******************************************************************************
 * 							Typedefs
 *******************************************************************************/

typedef enum {
	op_0dbm = 0x01,
	op_10dbm,
	op_14dbm,
	op_25dbm,
	op_27dbm
} RADIO_OutputPower_op;


typedef enum {
	dar_1k2bit = 0x01,
	dar_4k8bit,
	dar_19kbit,
	dar_32k7bit,
	dar_76k8bit,
	//dr_100kbit /* Not available on RC1180 */
} RADIO_DataRate_dar;


typedef enum {
	om_router,
	om_gateway,
	om_end
} RADIO_OpMode_om;

/*******************************************************************************
 * 							Function declarations
 *******************************************************************************/

bool 	RADIO_Init();
bool 	RADIO_Reset();

bool 	RADIO_SetMode(RADIO_OpMode_om mode);
void 	RADIO_SetCTS(bool clear);
void 	RADIO_SetBaudRate(int baud);

bool 	RADIO_EnterSleepMode();
bool 	RADIO_ExitSleepMode();

bool 	RADIO_ConfigMem(uint8_t * config);
bool 	RADIO_DefaultMemConfig();
bool 	RADIO_MemReset();

bool 	RADIO_SetDataRate_kbps(RADIO_DataRate_dar rate);
bool 	RADIO_SetOutputPower_dBm(RADIO_OutputPower_op power);
bool 	RADIO_SetChannel(uint8_t ch);
bool 	RADIO_SetSID(uint32_t * sid);

bool 	RADIO_UniqueID(bool set, uint32_t * uid);
float 	RADIO_GetRSSI_dBm();
int8_t 	RADIO_GetTemp_C();
float 	RADIO_GetVoltage_V();

#endif /* RADIO_DRIVER_H_ */
