/******************************************************************************
 * @file:		sd_driver.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	31. jan. 2016
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#ifndef SD_DRIVER_H_
#define SD_DRIVER_H_

#include <stdbool.h>
#include <stdint.h>

#include "integer.h"

/*******************************************************************************
 * 							Definitions for MMC/SDC command
 *******************************************************************************/

#define CMD0      (0)         /**< GO_IDLE_STATE */
#define CMD1      (1)         /**< SEND_OP_COND */
#define ACMD41    (41 | 0x80) /**< SEND_OP_COND (SDC) */
#define CMD8      (8)         /**< SEND_IF_COND */
#define CMD9      (9)         /**< SEND_CSD */
#define CMD10     (10)        /**< SEND_CID */
#define CMD12     (12)        /**< STOP_TRANSMISSION */
#define ACMD13    (13 | 0x80) /**< SD_STATUS (SDC) */
#define CMD16     (16)        /**< SET_BLOCKLEN */
#define CMD17     (17)        /**< READ_SINGLE_BLOCK */
#define CMD18     (18)        /**< READ_MULTIPLE_BLOCK */
#define CMD23     (23)        /**< SET_BLOCK_COUNT */
#define ACMD23    (23 | 0x80) /**< SET_WR_BLK_ERASE_COUNT (SDC) */
#define CMD24     (24)        /**< WRITE_BLOCK */
#define CMD25     (25)        /**< WRITE_MULTIPLE_BLOCK */
#define CMD41     (41)        /**< SEND_OP_COND (ACMD) */
#define CMD55     (55)        /**< APP_CMD */
#define CMD58     (58)        /**< READ_OCR */

/*******************************************************************************
 * 							Function declarations
 *******************************************************************************/

void 	SD_Init(void);
int 	SD_Select(void);
void 	SD_DeSelect(void);

void    SD_PowerOn(void);
void    SD_PowerOff(void);

int     SD_BlockRx(uint8_t *buff, uint32_t btr);
int     SD_BlockTx(const uint8_t *buff, uint8_t token);

uint8_t SD_SendCmd(uint8_t cmd, DWORD arg);
uint8_t SD_XferSpi(uint8_t data);

void    SD_SpiClkFast(void);
void    SD_SpiClkSlow(void);

bool    SD_TimeOutElapsed(void);
void    SD_TimeOutSet(uint32_t msec);


#endif /* SD_DRIVER_H_ */
