/******************************************************************************
 * @file:		spi_config.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	26. jan. 2016
 ******************************************************************************
 *	Configuration parameters for the SPI interface.
 ******************************************************************************/

#ifndef SPI_CONFIG_H_
#define SPI_CONFIG_H_

#include <stdbool.h>
#include <stdint.h>

#include "em_usart.h"
#include "em_gpio.h"
#include "em_cmu.h"

#include "imu_config.h"
#include "gps_config.h"


#define SPI_N_DEVICES		3

/*******************************************************************************
 * 								Ports and pins
 *******************************************************************************/

#define SPI_PORT  			gpioPortE

#define SPI_CS_PORT_GPS		gpioPortD
#define SPI_CS_PORT_IMU		gpioPortC
#define SPI_CS_PORT_SD		gpioPortD

#define SPI_MOSI_PIN    	7
#define SPI_MISO_PIN    	6
#define SPI_CLK_PIN     	5

#define SPI_CS_PIN_GPS		8
#define SPI_CS_PIN_IMU		10
#define SPI_CS_PIN_SD		7

/*******************************************************************************
 * 								SPI Settings
 *******************************************************************************/

#define SPI_USART       	USART0
#define SPI_LOC        		USART_ROUTE_LOCATION_LOC1
#define SPI_CMUCLOCK    	cmuClock_USART0
#define SPI_ROUTE			USART_ROUTE_TXPEN | USART_ROUTE_RXPEN | USART_ROUTE_CLKPEN


#define SPI_STD_CLOCK		1000000 // 1MHz

#define SPI_RX_IRQn			USART0_RX_IRQn
#define SPI_TX_IRQn			USART0_TX_IRQn


#define SPI_INIT_DEFAULT	\
{							\
	usartEnable,			\
	0,						\
	SPI_STD_CLOCK,			\
	usartDatabits8,			\
	true,					\
	true,					\
	usartClockMode0			\
}

#endif /* SPI_CONFIG_H_ */
