/******************************************************************************
 * @file:		tbr_config.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	31. jan. 2016
 *
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#ifndef TBR_CONFIG_H_
#define TBR_CONFIG_H_

#include "em_leuart.h"
#include "em_gpio.h"

#include "shared.h"

typedef enum {
	tc_getSerialNmode,
	tc_clockSync,
	tc_clockUpdate,
	tc_enterCmdMode,
	tc_exitCmdMode,
	tc_unixTimeStamp,
	tc_tempNoiseLogInt,
	tc_nTagDetections,
	tc_restart,
	tc_clearMem
} TBR_Command_tc;


/*******************************************************************************
 * 								Commands (FW 1.3)
 *******************************************************************************/

/* Listening mode commands */

#define TBR_GET_SERIAL_NORMAL_MODE		"?"
#define TBR_CLOCKSYNC					"(+)"
#define TBR_ENTER_COMMAND 				"TBR"

#define TBR_CLOCKSYNC_OK				"S1"
#define TBR_CLOCKUPDATE_OK				"S2"

/* Implemented for older firmware versions */
#define TBR_CLOCKSYNC_OK_2				"ACK01\r"
#define TBR_CLOCKUPDATE_OK_2			"ACK02\r"

/* Command mode "get" commands */

#define TBR_GET_SERIAL_NUMBER			"SN?"
#define TBR_GET_UNIX					"UT?"
#define TBR_GET_TEMP_LOG_INT			"LI?"
#define TBR_GET_N_TAG_DETECTIONS		"TD?"
#define TBR_GET_TAG_LOG 				"PT?"
#define TBR_GET_SENSOR_LOG 				"PS?"


/* Command mode "set" commands */

#define TBR_SET_TEMP_LOG_INT			"LI="
#define TBR_UPDATE_UNIX					"UT="


/* Actions */

#define TBR_RESTART						"RR!"
#define TBR_DELETEALL					"DD!"
#define TBR_EXIT_COMMAND 				"EX!"

/*******************************************************************************
 * 								Ports and pins
 *******************************************************************************/

#define TBR_PWR_PORT		gpioPortA
#define TBR_GPIO_PORT       gpioPortC
#define TBR_UART_PORT		gpioPortA

#define TBR_PWR_PIN			7
#define TBR_TX_PIN		    5
#define TBR_RX_PIN         	6
#define TBR_BIAS_PIN		1
#define TBR_RE_PIN        	5

#if USE_OLD_CONTROLLER
#define TBR_DE_PIN        	1
#else
#define TBR_DE_PIN        	2
#endif

/*******************************************************************************
 * 								UART Settings
 *******************************************************************************/

#define TBR_UART           	LEUART1
#define TBR_CMUCLOCK        cmuClock_LEUART1

#define TBR_ROUTE 		   	LEUART_ROUTE_RXPEN | LEUART_ROUTE_TXPEN
#define TBR_LOC             LEUART_ROUTE_LOCATION_LOC1


#define TBR_BAUDRATE 		115200
#define TBR_DATABITS		leuartDatabits8
#define TBR_PARITY			leuartNoParity
#define TBR_STOPBITS		leuartStopbits1

#define TBR_IRQn			LEUART1_IRQn

#define TBR_UART_INIT		\
{							\
	leuartEnable,			\
	0,						\
	TBR_BAUDRATE,			\
	TBR_DATABITS,			\
	TBR_PARITY,				\
	TBR_STOPBITS			\
}

#endif /* TBR_CONFIG_H_ */
