/******************************************************************************
 * @file:		spi_driver.c
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	26. jan. 2016
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#include "spi_driver.h"
#include "spi_config.h"

/*******************************************************************************
 * 								Public functions
 *******************************************************************************/


/*******************************************************************************
 * @brief Initiates the SPI interface and the defined CS pins.
 *******************************************************************************/
void SPI_Init(){

	/* Init synchronous operation */
	USART_InitSync_TypeDef init = SPI_INIT_DEFAULT;
	USART_InitSync(SPI_USART, &init);

	SPI_USART->ROUTE |= SPI_ROUTE | SPI_LOC;

	  /* IO configuration */
	GPIO_PinModeSet(SPI_PORT, SPI_MOSI_PIN, gpioModePushPull, 1);
	GPIO_PinModeSet(SPI_PORT, SPI_MISO_PIN, gpioModeInputPullFilter, 1);
	GPIO_PinModeSet(SPI_PORT, SPI_CLK_PIN, gpioModePushPull, 0);
	GPIO_PinModeSet(SPI_CS_PORT_GPS, SPI_CS_PIN_GPS, gpioModePushPull, 1);
	GPIO_PinModeSet(SPI_CS_PORT_IMU, SPI_CS_PIN_IMU, gpioModePushPull, 1);
	GPIO_PinModeSet(SPI_CS_PORT_SD, SPI_CS_PIN_SD, gpioModePushPull, 1);
}


/*******************************************************************************
 * @brief Disable SPI and GPIO pins.
 *******************************************************************************/
void SPI_DeInit(){

	USART_Reset(SPI_USART);

	GPIO_PinModeSet(SPI_PORT, SPI_MOSI_PIN,	gpioModeDisabled, 0);
	GPIO_PinModeSet(SPI_PORT, SPI_MISO_PIN, gpioModeDisabled, 0);
	GPIO_PinModeSet(SPI_PORT, SPI_CLK_PIN, gpioModeDisabled, 0);
	GPIO_PinModeSet(SPI_CS_PORT_GPS, SPI_CS_PIN_GPS, gpioModeDisabled, 0);
	GPIO_PinModeSet(SPI_CS_PORT_IMU, SPI_CS_PIN_IMU, gpioModeDisabled, 0);
	GPIO_PinModeSet(SPI_CS_PORT_SD, SPI_CS_PIN_SD, gpioModeDisabled, 0);
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
uint8_t SPI_SendReceiveByte(uint8_t data){

	return USART_SpiTransfer(SPI_USART, data);
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void SPI_TransferByte(uint8_t data){

	USART_SpiTransfer(SPI_USART, data);
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
uint8_t SPI_ReceiveByte(){

	return USART_SpiTransfer(SPI_USART, 0);
}

void SPI_SetCurrentClk(uint32_t clkFreq){

	USART_BaudrateSyncSet(SPI_USART, 0, clkFreq);
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
uint32_t SPI_GetCurrentClk(){

	return USART_BaudrateGet(SPI_USART);
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void SPI_Select(SPI_Device_spi device){

	switch(device){
	case spi_gps:
		if(SPI_GetCurrentClk() != GPS_SPI_CLOCK)
			SPI_SetCurrentClk(GPS_SPI_CLOCK);

		GPIO_PinOutClear(SPI_CS_PORT_GPS, SPI_CS_PIN_GPS);
		break;

	case spi_imu:
		if(SPI_GetCurrentClk() != IMU_SPI_CLOCK)
			SPI_SetCurrentClk(IMU_SPI_CLOCK);

		GPIO_PinOutClear(SPI_CS_PORT_IMU, SPI_CS_PIN_IMU);
		break;

	case spi_sdCard:
		GPIO_PinOutClear(SPI_CS_PORT_SD, SPI_CS_PIN_SD);
		break;
	}
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void SPI_DeSelect(SPI_Device_spi device){

	switch(device)
	{
	case spi_gps:
		GPIO_PinOutSet(SPI_CS_PORT_GPS, SPI_CS_PIN_GPS);
		break;

	case spi_imu:
		GPIO_PinOutSet(SPI_CS_PORT_IMU, SPI_CS_PIN_IMU);
		break;

	case spi_sdCard:
		GPIO_PinOutSet(SPI_CS_PORT_SD, SPI_CS_PIN_SD);
		break;
	}
}


/*******************************************************************************
 * 								Private functions
 *******************************************************************************/


//void SetCurrentConfig(SPI_Device_spi active){
//
//	if (activeConfig != active){
//
//		activeConfig = active;
//		USART_Reset(SPI_USART);
//		USART_InitSync(SPI_USART, &registeredConfigs[active]);
//
//		SPI_USART->ROUTE = SPI_ROUTE | SPI_LOC;
//
////			GPIO_PinModeSet(SPI_PORT, SPI_MOSI_PIN, gpioModePushPull, 1);
////
////			GPIO_PinModeSet(SPI_PORT, SPI_MISO_PIN, gpioModeInputPull, 0);
////
////			GPIO_PinModeSet(SPI_PORT, SPI_CLK_PIN, gpioModePushPull, 0);
////
////			GPIO_PinModeSet(SPI_CS_PORT_GPS, SPI_CS_PIN_GPS, gpioModePushPull, 1);
////
////			GPIO_PinModeSet(SPI_CS_PORT_IMU, SPI_CS_PIN_IMU, gpioModePushPull, 1);
////
////			GPIO_PinModeSet(SPI_CS_PORT_SD, SPI_CS_PIN_SD, gpioModePushPull, 1);
//	}
//}
//
//void SPI_RegisterConfig(SPI_Device_spi device, USART_InitSync_TypeDef config){
//
//	registeredConfigs[device] = config;
//}
