/******************************************************************************
 * @file:		device_manager.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	4. feb. 2016
 ******************************************************************************
 *	Handles the direct communication with the different peripherals;
 *	initialization, sleep/wake up, configuration, data acquisition, etc.
 *	Also manages all of the GPIO interrupts, peripheral clocks,
 *	user configuration.
 ******************************************************************************/

#ifndef DEVICE_MANAGER_H_
#define DEVICE_MANAGER_H_

#include "shared.h"

/******************************************************************************
 *								Typedefs
 ******************************************************************************/


typedef enum {
	led_red,
	led_yellow,
	led_green
} LED_Color_led;


/* Device configuration structure used to re-configure the pre-defined
 * configuration parameters.
 */
typedef struct {
	Device_dev 	device;
	bool		enable;
	bool 		alwaysOn;
	bool 		lightSleep;
	bool		setLightSleep; /* Define whether to set the provided value in "lightSleep" */
	uint32_t 	interval_s;
	uint16_t 	onPeriod_s;
} DEV_Config;


/******************************************************************************
 *							Function declarations
 ******************************************************************************/

bool 		DEV_Init();
bool 		DEV_InitAllDevices();

bool 		DEV_DataAv(Device_dev device);
bool 		DEV_CollectData(Device_dev device);
bool 		DEV_SyncTime();

bool 		DEV_ShutdownDevice(Device_dev device);
bool 		DEV_WakeUpDevice(Device_dev device);
bool		DEV_ConfigureDevice(Device_dev device);
bool 		DEV_ResetDevice(Device_dev device);

void 	 	DEV_SetLED(bool active, LED_Color_led color);
bool 		DEV_LightSleepDeviceActive();

bool 		DEV_SetUserConfig();
void		DEV_SetDeviceConfig(DEV_Config * config);

void		DEV_Error_Handler();

uint8_t * 	DEV_GetFlags(Device_dev device);
void 		DEV_ClearFlags(Device_dev device, uint8_t mask);
void 		DEV_SetFlags(Device_dev device, uint8_t mask);

#endif /* DEVICE_MANAGER_H_ */
