/******************************************************************************
 * @file:		err.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	5. mai 2016
 ******************************************************************************
 * Provides an ERROR structure, several enumerations and macros to enable
 * simple error handling throughout the design.
 ******************************************************************************/

#ifndef ERR_H_
#define ERR_H_

#include "shared.h"

typedef enum {
	err_connectionErr = 0,
	err_badCheckSum,
	err_nakRecv,
	err_dataNotValid,
	err_gpsFixTimeout,
	err_rxTimeout,
	err_txTimeout,
	err_simError,
	err_notEnabled,

	err_storageFull,
	err_noFile,
	err_badFileName,
	err_sdCardNotDetected,
	err_headerErr,
	err_sohTimeout,
	err_incompleteCmd,
	err_majorFailure,
	err_ok,
} ERR_Result_err;


typedef enum {
	or_drivers = N_DEVICES,
	or_file,
	or_deviceManager,
	or_communication,
	or_timeManager,
	or_powerManager,
	or_logManager,
	or_none
} ERR_ExceptionOrigin_or;


typedef enum {
	ret_resolved,
	ret_resolvedRetry,
	ret_notResolved
}ERR_ReturnValue_ret;


typedef struct {
	ERR_Result_err			erRes;
	ERR_ExceptionOrigin_or	origin;
	ERR_ReturnValue_ret		retVal;
	uint8_t					errCount; /* The error counter is incremented if the same error occurs over again */
} ERROR;


extern ERROR error; /* Error structure defined "extern" for public access */


#define ERR_RAISE(err, or)							\
{													\
	ERR_CHECK(err, or);								\
	error.retVal = ret_notResolved; 				\
	error.origin = (ERR_ExceptionOrigin_or)or;		\
	error.erRes = err;								\
}

#define ERR_CHECK(err, or)							\
{													\
	(error.erRes == (ERR_Result_err)err) && 		\
	(error.origin == (ERR_ExceptionOrigin_or)or) ?	\
	++error.errCount : (error.errCount = 0);	    \
}

#define ERR_RESET()					\
{									\
	error.origin = or_none;			\
	error.erRes = err_ok;			\
	error.retVal = ret_resolved;	\
}


#define ERROR_TO_STRING(err) 			\
	err == 0 ? "Connection error" : "?"	\


#endif /* ERR_H_ */
