/******************************************************************************
 * @file:		gsm_inet.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	24. apr. 2016
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#ifndef GSM_INET_H_
#define GSM_INET_H_

#include "shared.h"

#include "gsm_messages.h"

#define GSM_TCP_MAX_PACKET_LEN		1460
#define GSM_SERIAL_PACKET_TIMEOUT	2 /* 2 = 400ms, 3 = 600ms etc. */

/*******************************************************************************
 * 								Typedefs
 *******************************************************************************/


typedef struct {
	GSM_Query_sq 	cmd; 		/* GSM Query command */
	Device_dev  	deviceLog; 	/* Device log to access */
	char 			* file; 	/* File to access */
} GSM_TCPRequest;

typedef enum {
	tcp_server,
	tcp_client,
	tcp_notConnected
} GSM_TcpStat;


#define GSM_TCP_MSG_TO_QUERY(msg) msg < 1 ? msg + 1 : msg + 5
#define GSM_MSG_TO_DEV_LOG(msg) msg - 1

/*******************************************************************************
 * 							Function declarations
 *******************************************************************************/

bool 			GSM_IdentifyTCPRequest(GSM_TCPRequest * tcpRequest);

bool 			GSM_TransferData(const char * buf);
GSM_Query_sq 	GSM_IdentifyData();

GSM_TcpStat 	GSM_TcpStatus();
bool 			GSM_InTransparentMode();
bool 			GSM_ExitTransparentMode();
bool 			GSM_ReEnterTransparentMode();

void			GSM_SetApn(char * apn);
void 			GSM_SetStandardTcpPort(char * port);

bool 			GSM_ConnectToServer(bool transparentMode, char * ipAddr);
bool 			GSM_DisconnectFromServer();
bool 			GSM_EstablishTCPServer(bool transparentMode, char * ipAddr, uint8_t ipLen);
bool 			GSM_CloseTCPServer();
bool 			GSM_CloseCall();

#endif /* GSM_INET_H_ */
