/******************************************************************************
 * @file:		log_manager.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	8. feb. 2016
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#ifndef LOG_MANAGER_H_
#define LOG_MANAGER_H_

#include "shared.h"
#include "file.h"

#include "log_param.h"

/*****************************************************************************
 *								Settings
 ******************************************************************************/

#define LOG_SEND_RECV_TIMEOUT_MS		100

#define LOG_PARENT_DIR			"/LOC_LOG"
#define LOG_COMB_PAR_DIR		"/COMB_LOG"

#define LOG_GPS_DIR				LOG_PARENT_DIR "/GPS_LOG"
#define LOG_TBR_DIR				LOG_PARENT_DIR "/TBR_LOG"
#define LOG_GAUGE_DIR			LOG_PARENT_DIR "/GAUG_LOG"
#define LOG_AQUA_DIR			LOG_PARENT_DIR "/AQUA_LOG"
#define LOG_IMU_DIR				LOG_PARENT_DIR "/IMU_LOG"
#define LOG_WS_DIR				LOG_PARENT_DIR "/WS_LOG"

#define LOG_GPS_CDIR			LOG_COMB_PAR_DIR "/GPS_LOG"
#define LOG_TBR_CDIR			LOG_COMB_PAR_DIR "/TBR_LOG"
#define LOG_GAUGE_CDIR			LOG_COMB_PAR_DIR "/GAUG_LOG"
#define LOG_AQUA_CDIR			LOG_COMB_PAR_DIR "/AQUA_LOG"
#define LOG_IMU_CDIR			LOG_COMB_PAR_DIR "/IMU_LOG"
#define LOG_WS_CDIR				LOG_COMB_PAR_DIR "/WS_LOG"

/*****************************************************************************
 *								Typedefs
 ******************************************************************************/

typedef void (*OnNewFileTransfer)(char * fileName);
typedef void (*OnTransferComplete)();

typedef struct {
	char  	 * currentSavefile; /* Current log file in use */
	char 	 * lastReadFile;	/* Last file accessed from remote system */
	char   	 * dir;				/* Log file directory */
	uint32_t   lastReadPos; 	/* Last file position accessed from remote system */
} LOG_Properties;

typedef enum {
	am_appendToSpecifiedFile,
	am_appendToCurrentFile,
	am_readCurrentFile,
	am_readFromLast,
	am_readSpecifiedFile
} LOG_AccessMode_am;

typedef struct {
	/* The stream to access when sending or receiving data */
	Stream 				stream;

	/* LOG access mode */
	LOG_AccessMode_am   accessMode;

	Device_dev 			deviceLogToAccess;

	LOG_Type 			logToAccess;

	char * 				fileToAccess;

	/* Number of bytes to transfer in one packet */
	uint16_t 			nBytesToTransfer;

	/* Wait time after transferred packet(to let modem/radio send data) */
	uint8_t				waitAfterTransferEnd_ms;

	/* Function pointer to get the next log file to access */
	OnNewFileTransfer 	getNextFile;

	/* Function pointer to call on transfer complete */
	OnTransferComplete 	transferComplete;

}LOG_StreamArgs;

/*****************************************************************************
 *							Function declarations
 ******************************************************************************/

bool 		LOG_Init();

bool 		LOG_CreateDirectories(LOG_Type log);
bool 		LOG_CreateNewFile(Device_dev deviceLog, char * fName, LOG_Type log);
void		LOG_GetLastReadFile(Device_dev deviceLog, LOG_Type log, char * fName);
bool		LOG_Close(Device_dev deviceLog, LOG_Type log);
bool 		LOG_CloseAllOpen();
bool 		LOG_CloseOpParamFile();

bool 		LOG_LoadDeviceOpParam(Device_dev device, LOG_Type log);
bool 		LOG_SaveDeviceOpParam(Device_dev device, LOG_Type log);
bool 		LOG_LoadMiscOpParam(LOG_Param param);
bool 		LOG_SaveMiscOpParam(LOG_Param param);

bool 		LOG_NewDataAvailable(Device_dev deviceLog, LOG_Type log);
uint16_t 	LOG_ReceiveToBuf(Stream stream, uint8_t * buf);
bool 		LOG_TransferFromBuf(Stream stream, uint8_t * buf, uint16_t bytesToTransfer);
bool 		LOG_StreamFromStorage(LOG_StreamArgs * args);
bool 		LOG_StreamToStorage(LOG_StreamArgs * args);
bool 		LOG_WriteToStorage(Device_dev deviceLog, LOG_Type log, char * data, uint16_t dataLen);

#endif /* LOG_MANAGER_H_ */
