/******************************************************************************
 * @file:		log_param.h
 * @project:	BuoyController
 * @author:  	Ove
 * @version:	1.00
 * @created:	28. mai 2016
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#ifndef LOG_PARAM_H_
#define LOG_PARAM_H_

#include "shared.h"


/*****************************************************************************
 *								Settings
 ******************************************************************************/

/* These must be updated if parameters are added to the corresponding enumerations! */

#define LOG_USER_CONFIG_DEVICE_ITEMS	4 	/* Number of parameters per line for each device setting */
#define LOG_USER_CONFIG_MISC_ITEMS		8 	/* Number of user settings defined by the LOG_UserParam_user enum */
#define LOG_USER_CONFIG_MISC_ITEMS_LEN	20	/* Max length of input strings */

#define LOG_OP_PARAM_DEVICE_ITEMS		2 	/* Number of parameters per line for each device */
#define LOG_OP_PARAM_ITEMS				3 	/* Number of parameter settings defined by the LOG_Param enum */

#define LOG_MAX_LINE_LEN				60 	/* Max line length of the parameter -and user configuration files */

#define LOG_CONFIG_USER					"CONFIG.txt"
#define LOG_CONFIG						"PARAM.txt"


/* Op param settings in addition to the device related settings */
#define OP_PARAM_TO_STRING(param)								\
	param == param_tbrTagDetections ? "TagDetections:" : 		\
	param == param_lastReadTbrFlashCode ? "TbrFlashCode:" : "?" \


/* User config misc. items in addition to the device related settings
 * Add new string representations of parameters here, to be identified
 * in the user config file */
#define USER_PARAM_TO_STRING(config)				\
	config == user_remoteIp ? "Remote IP" :			\
	config == user_tcpPort ? "Port" :				\
	config == user_firstTimeOnly ? "First time" :	\
	config == user_apn ? "APN" :					\
	config == user_simPin ? "PIN" :					\
	config == user_sId ? "SID" : 					\
	config == user_uId ? "UID" :					\
	config == user_resetTbr ? "ResetTBR" : "?" 		\

/*****************************************************************************
 *								Typedefs
 ******************************************************************************/

typedef struct {
	uint32_t 	deviceOpConfig[LOG_USER_CONFIG_DEVICE_ITEMS][N_DEVICES];
	char * 		misc[LOG_USER_CONFIG_MISC_ITEMS];
	bool 		configFound[LOG_USER_CONFIG_MISC_ITEMS + N_DEVICES];
} LOG_UserConfig;

typedef struct {

} LOG_OpParams;

/* Log operational parameters used by the data logging system */
typedef enum {
	param_device = 0,    /* Must stay at the top! */
	param_tbrTagDetections,
	param_lastReadTbrFlashCode
} LOG_Param;


/* User parameters read from file. Add new parameters (at the end!) if need be */
typedef enum {
	user_sId = 0,
	user_uId,
	user_resetTbr,
	user_apn,
	user_simPin,
	user_firstTimeOnly,
	user_tcpPort,
	user_remoteIp
} LOG_UserParam_user;

typedef enum {
	type_local = 0,
	type_combined
} LOG_Type;

/*****************************************************************************
 *							Function declarations
 ******************************************************************************/

bool LOG_LoadUserConfig(LOG_UserConfig * config);
bool LOG_ClearUserParam(LOG_UserParam_user param);

bool LOG_LoadOpParam(Device_dev device, LOG_Param param, LOG_Type log, uint8_t maxStringLen, uint8_t nParams, ...);
bool LOG_SaveOpParam(Device_dev device, LOG_Param param, LOG_Type log, uint8_t nParams, ...);

#endif /* LOG_PARAM_H_ */
