/******************************************************************************
 * @file:		time_manager.h
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	6. feb. 2016
 ******************************************************************************
 *	The time manager manages the real time counter (RTC) and the system clock,
 *	and incorporates a task scheduler that calculates compare values for the
 *	next system wake up event. The major events are the wake up and shutdown
 *	of the different devices. In addition, other events are also available, and
 *	new custom events can easily be added.
 ******************************************************************************/

#ifndef TIME_MANAGER_H_
#define TIME_MANAGER_H_

#include "em_cmu.h"
#include "em_rtc.h"
#include "em_emu.h"
#include "em_letimer.h"
#include "em_int.h"

#include "shared.h"
#include "clock_tc.h"


/* Total number of misc. intervals */
#define TIME_N_MISC_INTERVALS		4

/* Set the intervals to zero to disable! */

#define TIME_IND_TIMEOUT			0//3600 * 1
#define TIME_MIDNIGHT_INTERVAL		3600 * 24
#define TIME_TEMP_COMP_INTERVAL 	60 * 10
#define TIME_WATCHDOG_INTERVAL		3600 * 1

#define TIME_IND_TIMEOUT_MASK		0x40000
#define TIME_MIDNIGHT_MASK			0x80000
#define TIME_TEMP_COMP_MASK			0x100000
#define TIME_WATCHDOG_MASK			0x200000

/* Position in the misc_intervals array */

#define TIME_IND_TIMEOUT_POS		0
#define TIME_MIDNIGHT_INTERVAL_POS	1
#define TIME_TEMP_COMP_INTERVAL_POS 2
#define TIME_WATCHDOG_INTERVAL_POS	3

/*****************************************************************************
 *								Typedefs
 ******************************************************************************/

typedef enum {
	event_none = 0,
	event_wakeupDevice,
	event_shutdownDevice,
	event_indicatorTimeout,
	event_rtcTempComp,
	event_midnight,
	event_watchdog
}TIME_Event;

/*****************************************************************************
 *							Function declarations
 ******************************************************************************/

void 		TIME_Init(struct timeval * inittime);

void 		TIME_Sleep(bool light);

TIME_Event 	TIME_GetEvent();
int8_t		TIME_DoTempComp();


#endif /* TIME_MANAGER_H_ */
