/******************************************************************************
 * @file:		fifo_tx.c
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	27. jan. 2016
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#include "fifo_tx.h"
#include "fifo_config.h"


static uint8_t 		TxQueueRadio[FIFO_TX_SIZE_RADIO];
static uint8_t 		TxQueueTbr[FIFO_TX_SIZE_TBR];
static uint8_t 		TxQueueAqua[FIFO_TX_SIZE_AQUA];
static uint8_t 		TxQueueWs[FIFO_TX_SIZE_WS];
static uint8_t 		TxQueueGprs[FIFO_TX_SIZE_GSM];
static uint16_t  	FifoTxSize[N_STREAM_DEVICES];

static uint8_t * 	TxQueuePtr[N_STREAM_DEVICES];

volatile static int TxQueueInPos[N_STREAM_DEVICES] = {0};
volatile static int TxQueueOutPos[N_STREAM_DEVICES] = {0};


/*******************************************************************************
 * @brief
 *******************************************************************************/
void FIFO_TX_Init(){

	TxQueuePtr[0] = &TxQueueRadio[0];
	TxQueuePtr[1] = &TxQueueTbr[0];
	TxQueuePtr[2] = &TxQueueAqua[0];
	TxQueuePtr[3] = &TxQueueWs[0];
	TxQueuePtr[4] = &TxQueueGprs[0];

	FifoTxSize[0] = FIFO_TX_SIZE_RADIO;
	FifoTxSize[1] = FIFO_TX_SIZE_TBR;
	FifoTxSize[2] = FIFO_TX_SIZE_AQUA;
	FifoTxSize[3] = FIFO_TX_SIZE_WS;
	FifoTxSize[4] = FIFO_TX_SIZE_GSM;
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void FIFO_TX_Reset(Stream stream){

	TxQueueInPos[stream] = 0;
	TxQueueOutPos[stream] = 0;
}


/*******************************************************************************
 * @brief
 * @return false if the buffer is full, otherwise true.
 *******************************************************************************/
bool FIFO_TX_Free(Stream stream){

	 if(TxQueueInPos[stream] == (( TxQueueOutPos[stream] - 1 +
			 FifoTxSize[stream]) % FifoTxSize[stream])){

		 return false; /* Queue Full */
	 }
	 else return true;
}


/*******************************************************************************
 * @brief
 * @return true if buffer is empty, otherwise false.
 *******************************************************************************/
bool FIFO_TX_Empty(Stream stream){

	return (TxQueueInPos[stream] == TxQueueOutPos[stream]);
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
bool FIFO_TX_Put(Stream stream, uint8_t data){

	bool res = true;

    if (TxQueueInPos[stream] == ((TxQueueOutPos[stream] - 1 +
    		FifoTxSize[stream]) % FifoTxSize[stream])){

    	res = false; /* Queue Full*/
    }
    else {
    	*(TxQueuePtr[stream] + TxQueueInPos[stream]) = data;

    	TxQueueInPos[stream] = (TxQueueInPos[stream] + 1) % FifoTxSize[stream];
    }

    return res;
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
bool FIFO_TX_Get(Stream stream, uint8_t * data){

	bool res = true;

    if (TxQueueInPos[stream] == TxQueueOutPos[stream]){

       res = false; /* Queue Empty - nothing to get */
    }

    else {

    	*data = *(TxQueuePtr[stream] + TxQueueOutPos[stream]);

    	TxQueueOutPos[stream] = (TxQueueOutPos[stream] + 1) % FifoTxSize[stream];
    }

    return res;
}
