/******************************************************************************
 * @file:		comStates.c
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	17. mai 2016
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#include "checkStates.h"
#include "deviceStates.h"
#include "comStates.h"
#include "updateStates.h"
#include "exceptionState.h"
#include "initState.h"

static bool radioConnectionTimeout = true;
static void OnConnectionDataTimeout();

/*******************************************************************************
 * 							Transition functions
 *******************************************************************************/


void TransitionToSendData(ControllerStatePtr state){

	DefaultImplementation(state);
	state->state = SendData;
}


void TransitionToReceiveData(ControllerStatePtr state){

	DefaultImplementation(state);

	if (state->currentDevice == dev_tbr700) state->state = CollectData;
	else state->state = ReceiveData;
}


void TransitionToSendSpecifiedMessage(ControllerStatePtr state){

	DefaultImplementation(state);
	state->state = SendSpecifiedMessage;
}


void TransitionToReceiveSms(ControllerStatePtr state){

	DefaultImplementation(state);
	state->currentDevice = dev_gsm;
	state->state = ReceiveSms;
}


void TransitionToWakeAndReceiveSms(ControllerStatePtr state){

	state->currentDevice = dev_gsm;
	state->state = WakeUpDevice;
	state->transition = TransitionToReceiveSms;
}


void TransitionToSendSms(ControllerStatePtr state){

	DefaultImplementation(state);
	state->currentDevice = dev_gsm;
	state->state = SendSms;
}


void TransitionToEndSession(ControllerStatePtr state){

	state->state = SendSpecifiedMessage;
	state->transition = TransitionToShutdownDevice;

}


/*******************************************************************************
 * 							 State functions
 *******************************************************************************/


/*******************************************************************************
 * @brief
 *******************************************************************************/
void SendSpecifiedMessage(ControllerStatePtr state){


	bool resOk = DEV_WakeUpDevice(dev_sdCard);

	if (resOk){

		BMP_Message * msg = BMP_GetMessage(*(BMP_MessageType_msg*)state->argPtr);

		resOk = COM_SendMessage(DEV_TO_STREAM(state->currentDevice), msg);
	}

	if (!resOk) OnException(state);
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void SendData(ControllerStatePtr state){


	bool resOk = DEV_WakeUpDevice(dev_sdCard);

	if (resOk) resOk = COM_Send(DEV_TO_STREAM(state->currentDevice));

	if (!resOk) OnException(state);
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void ReceiveData(ControllerStatePtr state){

#if DEBUG_OPERATION
	STREAM_Printf(stream_debug, "Receiving data from: %s\n", DEVICE_TO_STRING(state->currentDevice));
#endif

	/* Reset connection timeout timer */
	if (state->currentDevice == dev_gsm) ResetLETimer();

	bool resOk = DEV_WakeUpDevice(dev_sdCard);

	if (resOk) resOk = COM_Receive(DEV_TO_STREAM(state->currentDevice));

	if (!resOk) OnException(state);
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void SendSms(ControllerStatePtr state){

	bool resOk = GSM_SendStatusSMS();

	if (!resOk) OnException(state);
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void ReceiveSms(ControllerStatePtr state){

#if DEBUG_OPERATION
	STREAM_Printf(stream_debug, "Receiving SMS from: %s\n", DEVICE_TO_STRING(state->currentDevice));
#endif

	GSM_SmsRes_smsr smsRes = GSM_ReceiveSms();

	switch (smsRes){

	case smsr_ok_shutdown:
		state->transition = TransitionToShutdownDevice;
		/* Reset connection timeout timer */
		ResetLETimer();
		break;

	case smsr_ok_stayAwake:
		/* Start timer with timeout if no connection or data transfer */
		StartLETimer_s(60, OnConnectionDataTimeout);
		break;

	case smsr_error:
		OnException(state);
		break;
	}
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
static void OnConnectionDataTimeout(){

	if (radioConnectionTimeout) DEV_ShutdownDevice(dev_gsm);
}
