/******************************************************************************
 * @file:		deviceStates.c
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	17. mai 2016
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#include "checkStates.h"
#include "deviceStates.h"
#include "comStates.h"
#include "updateStates.h"
#include "exceptionState.h"
#include "initState.h"

/*******************************************************************************
 * 							Transition functions
 *******************************************************************************/


void TransitionToCollectData(ControllerStatePtr state){

	DefaultImplementation(state);
	state->state = CollectData;
}


void TransitionToWakeUpDevice(ControllerStatePtr state){

	DefaultImplementation(state);
	state->state = WakeUpDevice;

	OnWakeUpDevice(state);
}


void TransitionToShutdownDevice(ControllerStatePtr state){

	DefaultImplementation(state);
	state->state = ShutDownDevice;
}


void OnWakeUpDevice(ControllerStatePtr state){

	if (state->currentDevice == dev_gsm){

		state->transition = TransitionToSendSms;
	}

	else if (state->currentDevice == dev_radio){

		/* Start data acquisition if system is gateway node,
		 * and if the radio is not already awake */
		if (*SYS_GetID() == *SYS_GetGateway() &&
				(~*DEV_GetFlags(dev_radio) & DEV_ACTIVE_MASK)){

			SYS_StartDataAcquisition();
		}

		else if (~*DEV_GetFlags(dev_radio) & DEV_ACTIVE_MASK){

//			StartTimer_s(60, OnRadioTimeout);
		}
	}

	else if (*DEV_GetFlags(state->currentDevice) &
			DEV_COLLECT_DATA_MASK){

		state->transition = TransitionToCollectData;
	}
}


/*******************************************************************************
 * 							 State functions
 *******************************************************************************/


/*******************************************************************************
 * @brief
 *******************************************************************************/
void CollectData(ControllerStatePtr state){

#if DEBUG_OPERATION
	STREAM_Printf(stream_debug, "Collect data from: %s\n", DEVICE_TO_STRING(state->currentDevice));
#endif

	bool resOk = DEV_WakeUpDevice(dev_sdCard);

	if (resOk) resOk = DEV_CollectData(state->currentDevice);

	if (!resOk) OnException(state);

	else {

		/* Shut down device if shutdown has been called earlier */
		if (*DEV_GetFlags(state->currentDevice) & DEV_SHDWN_MASK){
			state->transition = TransitionToShutdownDevice;
		}

		/* Close log file and shut down SD card */
		if (LOG_Close(state->currentDevice, type_local)) DEV_ShutdownDevice(dev_sdCard);
	}
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void WakeUpDevice(ControllerStatePtr state){

#if DEBUG_OPERATION
	STREAM_Printf(stream_debug, "Wake up: %s\n", DEVICE_TO_STRING(state->currentDevice));
#endif

	bool resOk = DEV_WakeUpDevice(state->currentDevice);

	if (!resOk) OnException(state);
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void ShutDownDevice(ControllerStatePtr state){

#if DEBUG_OPERATION
	STREAM_Printf(stream_debug, "Shutdown: %s\n", DEVICE_TO_STRING(state->currentDevice));
#endif

	/* Delay to let radio process/forward data before shutdown */
	if (state->currentDevice == dev_radio) 	Sleep_ms(500, true);

	bool resOk = DEV_ShutdownDevice(state->currentDevice);

	if (!resOk) OnException(state);
}


static void OnRadioTimeout(){

	DEV_ShutdownDevice(dev_radio);
}
