/******************************************************************************
 * @file:		initState.c
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	17. mai 2016
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#include "checkStates.h"
#include "deviceStates.h"
#include "comStates.h"
#include "updateStates.h"
#include "exceptionState.h"
#include "initState.h"


/*******************************************************************************
 * 							Transition functions
 *******************************************************************************/


void TransitionToInitSystem(ControllerStatePtr state){

	DefaultImplementation(state);
	state->state = InitSystem;

#if (DEBUG_OPERATION > 1)
	state->transition = TransitionToCreateLogFiles;
#else
	state->transition = TransitionToUpdateTime;
#endif
}


/*******************************************************************************
 * 							 State functions
 *******************************************************************************/


/*******************************************************************************
 * @brief
 *******************************************************************************/
void InitSystem(ControllerStatePtr state){

	bool resOk = DEV_InitAllDevices();

	/* Load user configuration from file and configure */
	if (resOk) resOk = DEV_SetUserConfig();


	/* Configure all enabled devices */
	for (int i = 0; i < N_DEVICES; i++){

		if (resOk) resOk = DEV_ConfigureDevice(i);
	}

	/* Shut down all devices */
	for (int i = 0; i < N_DEVICES; i++){

		if (resOk) DEV_ShutdownDevice(i);
	}

	if (!resOk){
		OnException(state);
		return;
	}

	if (!indicatorTimeout){
		DEV_SetLED(true, led_green);
	}
}
