/******************************************************************************
 * @file:		updateStates.c
 * @project:	BuoyController
 * @author:  	Ove Nesse
 * @version:	1.00
 * @created:	17. mai 2016
 ******************************************************************************
 *	File info here
 ******************************************************************************/

#include "controllerState.h"

#include "checkStates.h"
#include "deviceStates.h"
#include "comStates.h"
#include "updateStates.h"
#include "exceptionState.h"
#include "initState.h"



/*******************************************************************************
 * 							Transition functions
 *******************************************************************************/


void TransitionToUpdateTime(ControllerStatePtr state){

	DefaultImplementation(state);
	state->state = UpdateTime;

	if(state->init) state->transition = TransitionToCreateLogFiles;
}


void TransitionToCreateLogFiles(ControllerStatePtr state){

	DefaultImplementation(state);
	state->state = CreateLogFiles;
}


void TransitionToTempComp(ControllerStatePtr state){

	DefaultImplementation(state);
	state->state = TempComp;
}


/*******************************************************************************
 * 							 State functions
 *******************************************************************************/


/*******************************************************************************
 * @brief
 *******************************************************************************/
void UpdateTime(ControllerStatePtr state){

	bool resOk = DEV_SyncTime();

	if (!resOk) OnException(state);

	else {

	#if DEBUG_OPERATION
		STREAM_Printf(stream_debug, "Clock update\n");
	#endif

		if(!indicatorTimeout){
			/* Signal that a valid UTC time has been acquired */
			DEV_SetLED(true, led_red);
			DEV_SetLED(true, led_yellow);
			Sleep_ms(1000, true);
			DEV_SetLED(false, led_red);
			DEV_SetLED(false, led_yellow);
		}
	}
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void CreateLogFiles(ControllerStatePtr state){


#if DEBUG_OPERATION
	STREAM_Printf(stream_debug, "New log files\n");
#endif

	bool resOk = DEV_WakeUpDevice(dev_sdCard);

	/* Init log parameters */
	if (state->init && resOk) LOG_Init();

	/* Make sure the log directories are present */
	if (resOk) resOk = LOG_CreateDirectories(type_local);

	for (int deviceLog = 0; deviceLog < N_LOG_DEVICES; deviceLog++){

		if (DEV_GetEnabledDevice(deviceLog) && resOk) resOk = LOG_CreateNewFile(
				deviceLog, SYS_MakeFileName(true, deviceLog, NULL), type_local);
	}

	/* Create combined log files for all systems
	 * if this is a gateway node (network master) */
	if (*SYS_GetID() == *SYS_GetGateway()){

		if (resOk) resOk = LOG_CreateDirectories(type_combined);

		for (int deviceLog = 0; deviceLog < N_LOG_DEVICES; deviceLog++){

			if (DEV_GetEnabledDevice(deviceLog) && resOk) resOk = LOG_CreateNewFile(
					deviceLog, SYS_MakeFileName(false, deviceLog, NULL), type_combined);

		}
	}

	LOG_CloseOpParamFile();

	if (!resOk) OnException(state);

	else {
		state->init = false;
//		state->transition = TransitionToWakeAndReceiveSms;
	}
}


/*******************************************************************************
 * @brief
 *******************************************************************************/
void TempComp(ControllerStatePtr state){

#if DEBUG_OPERATION
	STREAM_Printf(stream_debug, "Temperature compensation\n");
#endif

	int8_t temp = TIME_DoTempComp();
	SYS_UpdateOnBoardTemp(temp);
}
